// draw a simple leaf with two sides

// e is the angle of the leaf sides against the plane
// b is the bow initial angle. less means leaner leaves
// n is the number of line segments used to draw the leaf.

simple_leaf(e,b)	=> simple_leaf (e,b,8), 1;
simple_leaf(e,b,n)	=> [attr (distance, distance/n) [{.\(e)bow(b,n)}] {./(e)bow(-b,n)}], n+1;
bow(b,n)		=> +(b) attr (delta, b*2/(n-1)) seg;
seg			=> F - seg;
