//
// some fantasy flower
//

include (simple_leaf)
include (simple_petal)

fig(n)		=> tree(5), n;

tree(n)	: n	=> attr (color, '0.2 0.8 0) attr (width, 2) F(8) L /(137.5) tree(n-1);
tree(n)		=> F(10) attr (color, '1 1 0) attr (distance, 5) /(9) petal (10, 8);
L		=> [attr (width, 1) &(30) simple_leaf (30, 30) ^(15) F(15) attr (distance, 4) petal (80, 3)];

